# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['pyrolific',
 'pyrolific.api',
 'pyrolific.api.bonuses',
 'pyrolific.api.eligibility_requirements',
 'pyrolific.api.filter_sets',
 'pyrolific.api.filters',
 'pyrolific.api.hooks',
 'pyrolific.api.invitations',
 'pyrolific.api.messages',
 'pyrolific.api.participant_groups',
 'pyrolific.api.projects',
 'pyrolific.api.studies',
 'pyrolific.api.submissions',
 'pyrolific.api.surveys',
 'pyrolific.api.users',
 'pyrolific.api.workspaces',
 'pyrolific.models']

package_data = \
{'': ['*']}

install_requires = \
['attrs>=21.3.0', 'httpx>=0.15.4,<0.25.0', 'python-dateutil>=2.8.0,<3.0.0']

setup_kwargs = {
    'name': 'pyrolific',
    'version': '1.1',
    'description': 'Unofficial autogenerated openapi python client for api.prolific.co',
    'long_description': '# pyrolific\nAn unoffical client library for accessing Prolific API for researchers.\n\nGenerated with https://github.com/openapi-generators/openapi-python-client from https://docs.prolific.co/docs/api-docs/public-openapi.\n\n## Usage\nFirst, create a client:\n\n```python\nfrom pyrolific import Client\n\nclient = Client(base_url="https://api.prolific.co")\n```\n\nIf the endpoints you\'re going to hit require authentication, use `AuthenticatedClient` instead:\n\n```python\nfrom pyrolific import AuthenticatedClient\n\nclient = AuthenticatedClient(base_url="https://https://api.prolific.co", token="SuperSecretToken")\n```\n\nAuthenticatedClient doen\'t seem to work with the api, you still have to include an authorization kwarg on endpoint calls.\n\n```python\nfrom pyrolific.api.studies import get_api_v1_studies\nget_api_v1_studies.sync(client=client, authorization=\'Token SuperSecretToken\')\n```\n** Remainder of document unmodified autogenerated output from generator **\n\nOr do the same thing with an async version:\n\n```python\nfrom pyrolific.models import MyDataModel\nfrom pyrolific.api.my_tag import get_my_data_model\nfrom pyrolific.types import Response\n\nmy_data: MyDataModel = await get_my_data_model.asyncio(client=client)\nresponse: Response[MyDataModel] = await get_my_data_model.asyncio_detailed(client=client)\n```\n\nBy default, when you\'re calling an HTTPS API it will attempt to verify that SSL is working correctly. Using certificate verification is highly recommended most of the time, but sometimes you may need to authenticate to a server (especially an internal server) using a custom certificate bundle.\n\n```python\nclient = AuthenticatedClient(\n    base_url="https://internal_api.example.com", \n    token="SuperSecretToken",\n    verify_ssl="/path/to/certificate_bundle.pem",\n)\n```\n\nYou can also disable certificate validation altogether, but beware that **this is a security risk**.\n\n```python\nclient = AuthenticatedClient(\n    base_url="https://internal_api.example.com", \n    token="SuperSecretToken", \n    verify_ssl=False\n)\n```\n\nThere are more settings on the generated `Client` class which let you control more runtime behavior, check out the docstring on that class for more info.\n\nThings to know:\n1. Every path/method combo becomes a Python module with four functions:\n    1. `sync`: Blocking request that returns parsed data (if successful) or `None`\n    1. `sync_detailed`: Blocking request that always returns a `Request`, optionally with `parsed` set if the request was successful.\n    1. `asyncio`: Like `sync` but async instead of blocking\n    1. `asyncio_detailed`: Like `sync_detailed` but async instead of blocking\n\n1. All path/query params, and bodies become method arguments.\n1. If your endpoint had any tags on it, the first tag will be used as a module name for the function (my_tag above)\n1. Any endpoint which did not have a tag will be in `pyrolific.api.default`\n\n## Building / publishing this Client\nThis project uses [Poetry](https://python-poetry.org/) to manage dependencies  and packaging.  Here are the basics:\n1. Update the metadata in pyproject.toml (e.g. authors, version)\n1. If you\'re using a private repository, configure it with Poetry\n    1. `poetry config repositories.<your-repository-name> <url-to-your-repository>`\n    1. `poetry config http-basic.<your-repository-name> <username> <password>`\n1. Publish the client with `poetry publish --build -r <your-repository-name>` or, if for public PyPI, just `poetry publish --build`\n\nIf you want to install this client into another project without publishing it (e.g. for development) then:\n1. If that project **is using Poetry**, you can simply do `poetry add <path-to-this-client>` from that project\n1. If that project is not using Poetry:\n    1. Build a wheel with `poetry build -f wheel`\n    1. Install that wheel from the other project `pip install <path-to-wheel>`\n',
    'author': 'Ross Blair',
    'author_email': 'None',
    'maintainer': 'None',
    'maintainer_email': 'None',
    'url': 'https://github.com/rwblair/pyrolific',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.8,<4.0',
}


setup(**setup_kwargs)
